@@ -73,7 +73,7 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
         for base in cls.__bases__:
             method = self._find_method(base)
             if method:
-                return cast(_HoverMethod, method)
+                return method
 
         return None
 
@@ -116,12 +116,9 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
                 found_range = (
                     variable.name_range
                     if variable.source == namespace.source and position.is_in_range(variable.name_range, False)
-                    else cast(
-                        Optional[Range],
-                        next(
-                            (r.range for r in var_refs if position.is_in_range(r.range)),
-                            None,
-                        ),
+                    else next(
+                        (r.range for r in var_refs if position.is_in_range(r.range)),
+                        None,
                     )
                 )
                 value = None
@@ -163,17 +160,15 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
                     else:
                         value = ""
 
-                    text = f"### {variable.type.value.title()} `{variable.name}`\n\n"
+                    text = f"### {variable.type.value.title()} `{variable.convertable_name}`\n\n"
 
                     if value:
-
                         text += "```python\n"
                         text += f"value: {type(real_value).__name__} = {value}\n"
                         text += "```\n"
 
                     text += "\n"
             if text:
-
                 return Hover(
                     contents=MarkupContent(kind=MarkupKind.MARKDOWN, value=text),
                     range=highlight_range,
@@ -189,12 +184,9 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
                 found_range = (
                     kw.name_range
                     if kw.source == namespace.source and position.is_in_range(kw.name_range, False)
-                    else cast(
-                        Optional[Range],
-                        next(
-                            (r.range for r in kw_refs if position.is_in_range(r.range, False)),
-                            None,
-                        ),
+                    else next(
+                        (r.range for r in kw_refs if position.is_in_range(r.range, False)),
+                        None,
                     )
                 )
 
@@ -233,12 +225,9 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelper):
                     else (
                         ns.alias_range
                         if ns.import_source == namespace.source and position.is_in_range(ns.alias_range, False)
-                        else cast(
-                            Optional[Range],
-                            next(
-                                (r.range for r in ns_refs if position.is_in_range(r.range, False)),
-                                None,
-                            ),
+                        else next(
+                            (r.range for r in ns_refs if position.is_in_range(r.range, False)),
+                            None,
                         )
                     )
                 )
